==> haskell-wai-handler-launch-3.0.3.1-604-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-handler-launch.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 wai-handler-launch
version:              3.0.3.1
visibility:           public
id:                   wai-handler-launch-3.0.3.1-8IgKbUJCBab1oJIWhdnppG
key:                  wai-handler-launch-3.0.3.1-8IgKbUJCBab1oJIWhdnppG
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
synopsis:             Launch a web app in the default browser.
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-handler-launch>.

category:             Web
abi:                  fce100fc750c5a6ca34fabce8e050f48
exposed:              True
exposed-modules:      Network.Wai.Handler.Launch
import-dirs:          /usr/lib/ghc-9.2.8/site-local/wai-handler-launch-3.0.3.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/wai-handler-launch-3.0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-handler-launch
hs-libraries:         HSwai-handler-launch-3.0.3.1-8IgKbUJCBab1oJIWhdnppG
depends:
    async-2.2.5-EP8h1wWlEwVFRsNBoUfgIV base-4.16.4.0
    bytestring-0.11.4.0 http-types-0.12.4-IbDJVwQVDeTAnHs7wyLMrJ
    process-1.6.16.0 streaming-commons-0.2.2.6-4ZOdAHmSjPG6XiNhsEvYWl
    transformers-0.5.6.2 wai-3.2.4-BbAdcKGl4jbBaSv8iBtxy6
    warp-3.3.30-h30kJzvF9BHT39ymLaaUc

haddock-interfaces:
    /usr/share/doc/haskell-wai-handler-launch/html/wai-handler-launch.haddock

haddock-html:         /usr/share/doc/haskell-wai-handler-launch/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-handler-launch-3.0.3.1-621-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-handler-launch.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 wai-handler-launch
version:              3.0.3.1
visibility:           public
id:                   wai-handler-launch-3.0.3.1-EUbBxrguFIkGpkdAUMGAyT
key:                  wai-handler-launch-3.0.3.1-EUbBxrguFIkGpkdAUMGAyT
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
synopsis:             Launch a web app in the default browser.
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-handler-launch>.

category:             Web
abi:                  c113470d0dc9025fcdd3f80060d104bd
exposed:              True
exposed-modules:      Network.Wai.Handler.Launch
import-dirs:          /usr/lib/ghc-9.2.8/site-local/wai-handler-launch-3.0.3.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/wai-handler-launch-3.0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-handler-launch
hs-libraries:         HSwai-handler-launch-3.0.3.1-EUbBxrguFIkGpkdAUMGAyT
depends:
    async-2.2.5-Hxx4nU8aNwh7V1GfZTZX85 base-4.16.4.0
    bytestring-0.11.4.0 http-types-0.12.4-4jA7skhyc4O1mTcupRz8pv
    process-1.6.16.0 streaming-commons-0.2.2.6-BYBDcyumTobELXYn1pU9hC
    transformers-0.5.6.2 wai-3.2.4-JIqkXCnMPAzFKNQzPpgW2q
    warp-3.3.30-A59ReqdFC07LgOaV7Ls0Bk

haddock-interfaces:
    /usr/share/doc/haskell-wai-handler-launch/html/wai-handler-launch.haddock

haddock-html:         /usr/share/doc/haskell-wai-handler-launch/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
